package Class::MOP::Class::Immutable::Class::MOP::Class;

use strict;
use warnings;

our $VERSION   = '0.84';
$VERSION = eval $VERSION;
our $AUTHORITY = 'cpan:STEVAN';

use base qw(Class::MOP::Class::Immutable::Trait Class::MOP::Class);

1;

__END__

=pod

=head1 NAME

Class::MOP::Class::Immutable::Class::MOP::Class - An immutable subclass of Class::MOP::Class

=head1 DESCRIPTION

This is an empty class which inherits from
L<Class::MOP::Class::Immutable::Trait> and L<Class::MOP::Class>.

=head1 AUTHOR

Yuval Kogman E<lt>nothingmuch@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2009 by Infinity Interactive, Inc.

L<http://www.iinteractive.com>

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

